scale_scores.Rd
Get the scaled scores used in the T-scores.
scale_scores(scores)
An object of class npsych_scores.
npsych_scores
A numeric value. The function will error if scores is not of class npsych_scores or if its subclass is not one of names(ss).
scores
names(ss)